from olxbrasil.parsers.car_parser import CarParser
from olxbrasil.parsers.item_parser import ItemParser
from olxbrasil.parsers.list_parser import ListParser

__all__ = ("CarParser", "ItemParser", "ListParser")



from olxbrasil.exceptions import OlxRequestError, FilterNotFoundError
from olxbrasil.filters import ItemFilter, LocationFilter
from olxbrasil.service import Olx, AsyncOlx

__all__ = (
    "Olx",
    "AsyncOlx",
    "ItemFilter",
    "LocationFilter",
    "OlxRequestError",
    "FilterNotFoundError",
)



from olxbrasil.parsers.item_parser import ItemParser


class CarParser(ItemParser):
    def is_flex(self) -> bool:
        return self.properties["fuel"].lower().strip() == "flex"

    def is_exchangeable(self) -> str:
        return self.properties["exchange"].lower().strip() == "sim"

    def is_sole_owner(self):
        return self.properties["owner"].lower().strip() == "sim"

    def is_tax_paid(self):
        return self.properties["financial"].lower().strip() == "ipva pago"



class OlxRequestError(Exception):
    """Raised when is not possible to do a successful request to OLX"""

    pass


class FilterNotFoundError(Exception):
    """Raised when a filter was passed wrongly"""

    pass



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['olxbrasil', 'olxbrasil.parsers']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.9.3,<5.0.0',
 'fake-useragent>=0.1.11,<0.2.0',
 'httpx>=0.17.0,<0.18.0']

setup_kwargs = {
    'name': 'olxbrasil',
    'version': '0.2.0',
    'description': 'Biblioteca para scrapping da Olx Brasil (olx.com.br)',
    'long_description': None,
    'author': 'Marcelo Lino',
    'author_email': 'mdslino@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
